# mira [![CircleCI](https://circleci.com/gh/faustomorales/mira.svg?style=shield)](https://circleci.com/gh/faustomorales/mira) [![Documentation Status](https://readthedocs.org/projects/mira-python/badge/?version=latest)](https://mira-python.readthedocs.io/en/latest/?badge=latest)

mira provides tooling for simple object detection projects. The package spans three areas of focus.

- **Core** object detection abstractions for images and annotations
- Access to **datasets** from common formats (e.g., VOC, COCO) and image sets (e.g., VOC 2012)
- A common API to for **well-known models** (e.g., EfficientDet and FasterRCNN)

Check out [the docs](https://mira-python.readthedocs.io/en/latest/).

## Installation

```shell
pip install mira
```
